# Art Project

import board, neopixel, time, digitalio, math, touchio, audiomixer, audiocore
from audiocore import WaveFile

try:
    from audioio import AudioOut
except ImportError:
    try:
        from audiopwmio import PWMAudioOut as AudioOut
    except ImportError:
        print("This board does not support AudioOut")
        pass # Not all boards can play audio with AudioOut

from adafruit_led_animation.color import (
    AMBER, #(255, 100, 0)
    AQUA, # (50, 255, 255)
    BLACK, #OFF (0, 0, 0)
    BLUE, # (0, 0, 255)
    CYAN, # (0, 255, 255)
    GOLD, # (255, 222, 30)
    GREEN, # (0, 255, 0)
    JADE, # (0, 255, 40)
    MAGENTA, #(255, 0, 20)
    OLD_LACE, # (253, 245, 230)
    ORANGE, # (255, 40, 0)
    PINK, # (242, 90, 255)
    PURPLE, # (180, 0, 255)
    RED, # (255, 0, 0)
    TEAL, # (0, 255, 120)
    WHITE, # (255, 255, 255)
    YELLOW, # (255, 150, 0)
    RAINBOW # a list of colors to cycle through
    # RAINBOW is RED, ORANGE, YELLOW, GREEN, BLUE, and PURPLE ((255, 0, 0), (255, 40, 0), (255, 150, 0), (0, 255, 0), (0, 0, 255), (180, 0, 255))
)

INDIGO = (63, 0, 255)
VIOLET = (127, 0, 255)
LIGHT_BLUE = (173,255,209)
GREEN_YELLOW = (154, 205, 50)
LIGHT_GREEN = (144, 238, 144)
LIGHT_YELLOW = (241, 235, 156)

BASE_COLORS = [RED, BLUE, GREEN, YELLOW, WHITE]

speaker = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker.direction = digitalio.Direction.OUTPUT
speaker.value = True
audio = AudioOut(board.SPEAKER)

pixels_strip = board.NEOPIXEL
pixels_num_lights = 10
pixels = neopixel.NeoPixel(pixels_strip, pixels_num_lights, brightness = .7, auto_write = True)

pad = [board.A1, board.A2, board.A3, board.A4, board.A5, board.A6]
touchpad = []
for i in range (len(pad)):
    touchpad.append(touchio.TouchIn(pad[i]))

color_1 = BLACK
color_2 = BLACK
final_color = BLACK

set_color_1 = False
set_color_2 = False

button_A = digitalio.DigitalInOut(board.BUTTON_A)
button_A.switch_to_input(pull=digitalio.Pull.DOWN)

button_B = digitalio.DigitalInOut(board.BUTTON_B)
button_B.switch_to_input(pull=digitalio.Pull.DOWN)


path = "sounds/"

def play_sound(filename):
    with open(path + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            if (touchpad[5].value):
                break

beats = ["red.wav", "blue.wav", "green.wav", "yellow.wav", "white.wav"]

play_file1 = 0
play_file2 = 0

while True:
    # Default mode = color display mode
    # Button A sets color 1
    # Button B sets color 2
    # Touchpad 6 in both situations resets both colors
    while color_1 == BLACK or color_2 == BLACK:
        if touchpad[5].value:
            pixels.fill(BLACK)
            color_1 = BLACK
            color_2 = BLACK
            play_file = ""
        if button_A.value and set_color_1 == False:
            # One beep for 1
            #play_sound_button("beep.wav")
            set_color_1 = True
            set_color_2 = False
            print("Set color 1")
        if button_B.value and set_color_2 == False:
            # Two beeps for 2
            #play_sound_button("beep.wav")
            #play_sound_button("beep.wav")
            set_color_2 = True
            set_color_1 = False
            print("Set color 2")
        # Set color one
        if set_color_1 == True:
            pixels.fill(BLACK)
            for i in range(len(BASE_COLORS)):
                if touchpad[i].value:
                    if touchpad[5].value:
                        pixels.fill(BLACK)
                        color_1 = BLACK
                        color_2 = BLACK
                        set_color_1 = False
                        set_color_2 = False
                        play_file = ""
                    color_1 = BASE_COLORS[i]
                    pixels.fill(color_1)
                    print(f"Color 1 is {color_1}")
                    play_file1 = i
                    play_sound(beats[i])
                    if color_1 != BLACK:
                        set_color_1 = False
        # Set color 2
        if set_color_2 == True:
            pixels.fill(BLACK)
            for i in range(len(BASE_COLORS)):
                if touchpad[i].value:
                    if touchpad[5].value:
                        pixels.fill(BLACK)
                        color_1 = BLACK
                        color_2 = BLACK
                        set_color_1 = False
                        set_color_2 = False
                        play_file = ""
                    color_2 = BASE_COLORS[i]
                    pixels.fill(color_2)
                    print(f"Color 2 is {color_2}")
                    play_file2 = i
                    play_sound(beats[i])
                    if color_2 != BLACK:
                        set_color_2 = False

    # NOW MIX COLORS

    #Color 1 is red
    time.sleep(.5)
    if color_1 ==  RED and color_2 == RED:
        final_color = RED
    if color_1 ==  RED and color_2 == BLUE:
        final_color = PURPLE
    if color_1 ==  RED and color_2 == GREEN:
        final_color = YELLOW
    if color_1 ==  RED and color_2 == YELLOW:
        final_color = ORANGE
    if color_1 ==  RED and color_2 == WHITE:
        final_color = PINK
    #Color 1 is Blue
    if color_1 ==  BLUE and color_2 == RED:
        final_color = PURPLE
    if color_1 ==  BLUE and color_2 == BLUE:
        final_color = BLUE
    if color_1 ==  BLUE and color_2 == GREEN:
        final_color = CYAN
    if color_1 ==  BLUE and color_2 == YELLOW:
        final_color = GREEN
    if color_1 ==  BLUE and color_2 == WHITE:
        final_color = LIGHT_BLUE
    #Color 1 is GREEN
    if color_1 ==  GREEN and color_2 == RED:
        final_color = YELLOW
    if color_1 ==  GREEN and color_2 == BLUE:
        final_color = CYAN
    if color_1 ==  GREEN and color_2 == GREEN:
        final_color = GREEN
    if color_1 ==  GREEN and color_2 == YELLOW:
        final_color = GREEN_YELLOW
    if color_1 ==  GREEN and color_2 == WHITE:
        final_color = LIGHT_GREEN
    #Color 1 is YELLOW
    if color_1 ==  YELLOW and color_2 == RED:
        final_color = ORANGE
    if color_1 ==  YELLOW and color_2 == BLUE:
        final_color = GREEN
    if color_1 ==  YELLOW and color_2 == GREEN:
        final_color = GREEN_YELLOW
    if color_1 ==  YELLOW and color_2 == YELLOW:
        final_color = YELLOW
    if color_1 ==  YELLOW and color_2 == WHITE:
        final_color = LIGHT_YELLOW
    #Color 1 is WHITE
    if color_1 ==  WHITE and color_2 == RED:
        final_color = PINK
    if color_1 ==  WHITE and color_2 == BLUE:
        final_color = LIGHT_BLUE
    if color_1 ==  WHITE and color_2 == GREEN:
        final_color = LIGHT_GREEN
    if color_1 ==  WHITE and color_2 == YELLOW:
        final_color = LIGHT_YELLOW
    if color_1 ==  WHITE and color_2 == WHITE:
        final_color = WHITE
    pixels.fill(final_color)
    print(final_color)
    while not(touchpad[5].value):
        play_sound(beats[play_file1])
        play_sound(beats[play_file2])
    color_1 = BLACK
    color_2 = BLACK

